==> CGFBApp-1.0.7.tar.gz: CGFBApp/function.admin_dflttemplates_tab.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGFBApp (c) 2010 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  A toolbox of conveniences to build facebook integration into a website
#  for CMS modules and website designers.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

echo cge_template_admin::get_start_template_form($this,$id,'',
						 CGFBApp::TPL_SYSDFLT_INVITE,
						 'defaultadmin','dflt_templates',
						 $this->Lang('title_sysdflt_invite'),
						 'orig_invite.tpl');

#
# EOF
#
?>

==> CGFBApp-1.0.9.tar.gz: CGFBApp/function.admin_dflttemplates_tab.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGFBApp (c) 2010 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  A toolbox of conveniences to build facebook integration into a website
#  for CMS modules and website designers.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

echo cge_template_admin::get_start_template_form($this,$id,'',
						 CGFBApp::TPL_SYSDFLT_INVITE,
						 'defaultadmin','dflt_templates',
						 $this->Lang('title_sysdflt_invite'),
						 'orig_invite.tpl');

if( $this->GetPreference('dofeuauth') ) {
  echo cge_template_admin::get_start_template_form($this,$id,'',
						   CGFBApp::TPL_SYSDFLT_LOGIN,
						   'defaultadmin','dflt_templates',
						   $this->Lang('title_sysdflt_login'),
						   'orig_login.tpl');

  echo cge_template_admin::get_start_template_form($this,$id,'',
						   CGFBApp::TPL_SYSDFLT_LOGOUT,
						   'defaultadmin','dflt_templates',
						   $this->Lang('title_sysdflt_logout'),
						   'orig_logout.tpl');
}

#
# EOF
#
?>
